@@ -19,23 +19,20 @@
 #  DEALINGS IN THE SOFTWARE.
 """Shell Dependency Module."""
 
-import os
-import shlex
+import logging
 
-import sh
-
-from molecule import logger, util
 from molecule.dependency import base
+from molecule.util import BakedCommand
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class Shell(base.Base):
     """
     ``Shell`` is an alternate dependency manager.
 
-    It is intended to run a command in situations where `Ansible Galaxy`_ and
-    `Gilt`_ don't suffice.
+    It is intended to run a command in situations where `Ansible Galaxy`_
+    don't suffice.
 
     The ``command`` to execute is required, and is relative to Molecule's
     project directory when referencing a script not in $PATH.
@@ -87,24 +84,9 @@ class Shell(base.Base):
     def default_options(self):
         return {}
 
-    @property
-    def default_env(self):
-        return util.merge_dicts(os.environ, self._config.env)
-
-    def bake(self):
-        """
-        Bake a ``shell`` command so it's ready to execute and returns None.
-
-        :return: None
-        """
-        command_list = shlex.split(self.command)
-        command, args = command_list[0], command_list[1:]
-
-        self._sh_command = getattr(sh, command)
-        # Reconstruct command with remaining args.
-        self._sh_command = self._sh_command.bake(
-            args, _env=self.env, _out=LOG.out, _err=LOG.error
-        )
+    def bake(self) -> None:
+        """Bake a ``shell`` command so it's ready to execute."""
+        self._sh_command = BakedCommand(cmd=self.command, env=self.env)
 
     def execute(self):
         if not self.enabled:
