@@ -19,10 +19,12 @@
 #  DEALINGS IN THE SOFTWARE.
 """Delegated Driver Module."""
 
-from molecule import logger, util
+import logging
+
+from molecule import util
 from molecule.api import Driver
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class Delegated(Driver):
