@@ -25,7 +25,6 @@ import pytest
 
 from molecule import config, util
 from molecule.provisioner import ansible, ansible_playbooks
-from molecule.test.conftest import is_subset
 
 
 @pytest.fixture
@@ -101,7 +100,8 @@ def test_default_config_options_property(_instance):
             "display_failed_stderr": True,
             "forks": 50,
             "host_key_checking": False,
-            "interpreter_python": "auto",
+            # https://docs.ansible.com/ansible/devel/reference_appendices/interpreter_discovery.html
+            "interpreter_python": "auto_silent",
             "nocows": 1,
             "retry_files_enabled": False,
         },
@@ -147,7 +147,7 @@ def test_config_options_property(_instance):
             "foo": "bar",
             "forks": 50,
             "host_key_checking": False,
-            "interpreter_python": "auto",
+            "interpreter_python": "auto_silent",
             "nocows": 1,
             "retry_files_enabled": False,
         },
@@ -202,7 +202,11 @@ def test_env_property(_instance):
     "config_instance", ["_provisioner_section_data"], indirect=True
 )
 def test_env_appends_env_property(_instance):
-    x = [
+
+    # molecule could decide to add extra paths, so we only want to check
+    # that those that we need are kept inside the list
+    roles_path_list = _instance.env["ANSIBLE_ROLES_PATH"].split(":")
+    for x in [
         util.abs_path(
             os.path.join(_instance._config.scenario.ephemeral_directory, "roles")
         ),
@@ -213,8 +217,8 @@ def test_env_appends_env_property(_instance):
         "/usr/share/ansible/roles",
         "/etc/ansible/roles",
         util.abs_path(os.path.join(_instance._config.scenario.directory, "foo", "bar")),
-    ]
-    assert x == _instance.env["ANSIBLE_ROLES_PATH"].split(":")
+    ]:
+        assert x in roles_path_list
 
     x = _instance._get_modules_directories()
     x.append(
@@ -277,132 +281,6 @@ def test_links_property(_instance):
     assert {} == _instance.links
 
 
-@pytest.mark.parametrize(
-    "config_instance", ["_provisioner_section_data"], indirect=True
-)
-def test_inventory_property(_instance):
-    x = {
-        "ungrouped": {"vars": {}},
-        "bar": {
-            "hosts": {"instance-1": {"foo": "bar", "ansible_connection": "docker"}},
-            "children": {
-                "child1": {
-                    "hosts": {
-                        "instance-1": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                }
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "all": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "foo": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "children": {
-                "child1": {
-                    "hosts": {
-                        "instance-1": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                },
-                "child2": {
-                    "hosts": {
-                        "instance-2": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                },
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "baz": {
-            "hosts": {"instance-2": {"foo": "bar", "ansible_connection": "docker"}},
-            "children": {
-                "child2": {
-                    "hosts": {
-                        "instance-2": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                }
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-    }
-
-    assert is_subset(x, _instance.inventory)
-
-
-@pytest.mark.parametrize(
-    "config_instance", ["_provisioner_section_data"], indirect=True
-)
-def test_inventory_property_handles_missing_groups(temp_dir, _instance):
-    platforms = [{"name": "instance-1"}, {"name": "instance-2"}]
-    _instance._config.config["platforms"] = platforms
-
-    x = {
-        "ungrouped": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "vars": {},
-        },
-        "all": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-    }
-
-    assert is_subset(x, _instance.inventory)
-
-
 def test_inventory_directory_property(_instance):
     x = os.path.join(_instance._config.scenario.ephemeral_directory, "inventory")
     assert x == _instance.inventory_directory
@@ -437,45 +315,16 @@ def test_playbooks_cleaned_property_is_optional(_instance):
     assert _instance.playbooks.cleanup is None
 
 
-def test_playbooks_create_property(_instance):
-    x = os.path.join(
-        _instance._config.provisioner.playbooks._get_playbook_directory(),
-        "docker",
-        "create.yml",
-    )
-
-    assert x == _instance.playbooks.create
-
-
 def test_playbooks_converge_property(_instance):
     x = os.path.join(_instance._config.scenario.directory, "converge.yml")
 
     assert x == _instance.playbooks.converge
 
 
-def test_playbooks_destroy_property(_instance):
-    x = os.path.join(
-        _instance._config.provisioner.playbooks._get_playbook_directory(),
-        "docker",
-        "destroy.yml",
-    )
-
-    assert x == _instance.playbooks.destroy
-
-
 def test_playbooks_side_effect_property(_instance):
     assert _instance.playbooks.side_effect is None
 
 
-@pytest.mark.parametrize(
-    "config_instance", ["_provisioner_section_data"], indirect=True
-)
-def test_connection_options(_instance):
-    x = {"ansible_connection": "docker", "foo": "bar"}
-
-    assert is_subset(x, _instance.connection_options("foo"))
-
-
 def test_check(_instance, mocker, _patched_ansible_playbook):
     _instance.check()
 
@@ -697,103 +546,6 @@ def test_add_or_update_vars_does_not_create_vars(_instance):
     assert not os.path.isfile(hosts)
 
 
-@pytest.mark.parametrize(
-    "config_instance", ["_provisioner_section_data"], indirect=True
-)
-def test_write_inventory(temp_dir, _instance):
-    _instance._write_inventory()
-
-    assert os.path.isfile(_instance.inventory_file)
-
-    data = util.safe_load_file(_instance.inventory_file)
-
-    x = {
-        "ungrouped": {"vars": {}},
-        "bar": {
-            "hosts": {"instance-1": {"foo": "bar", "ansible_connection": "docker"}},
-            "children": {
-                "child1": {
-                    "hosts": {
-                        "instance-1": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                }
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "all": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "foo": {
-            "hosts": {
-                "instance-1": {"foo": "bar", "ansible_connection": "docker"},
-                "instance-2": {"foo": "bar", "ansible_connection": "docker"},
-            },
-            "children": {
-                "child1": {
-                    "hosts": {
-                        "instance-1": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                },
-                "child2": {
-                    "hosts": {
-                        "instance-2": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                },
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-        "baz": {
-            "hosts": {"instance-2": {"foo": "bar", "ansible_connection": "docker"}},
-            "children": {
-                "child2": {
-                    "hosts": {
-                        "instance-2": {"foo": "bar", "ansible_connection": "docker"}
-                    }
-                }
-            },
-            "vars": {
-                "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
-                "molecule_yml": "{{ lookup('file', molecule_file) | molecule_from_yaml }}",
-                "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
-                "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
-                "molecule_yml.provisioner.log|default(False) | bool }}",
-            },
-        },
-    }
-
-    assert is_subset(x, data)
-
-
 @pytest.mark.parametrize(
     "config_instance", ["_provisioner_section_data"], indirect=True
 )
