@@ -188,14 +188,26 @@ def test_get_config(config_instance):
 
 
 def test_get_config_with_base_config(config_instance):
-    config_instance.args = {"base_config": "./foo.yml"}
+    config_instance.args = {"base_config": ["./foo.yml"]}
     contents = {"foo": "bar"}
-    util.write_file(config_instance.args["base_config"], util.safe_dump(contents))
+    util.write_file(config_instance.args["base_config"][0], util.safe_dump(contents))
     result = config_instance._get_config()
 
     assert result["foo"] == "bar"
 
 
+def test_get_config_with_multiple_base_configs(config_instance):
+    config_instance.args = {"base_config": ["./foo.yml", "./foo2.yml"]}
+    contents = {"foo": "bar", "foo2": "bar"}
+    util.write_file(config_instance.args["base_config"][0], util.safe_dump(contents))
+    contents = {"foo2": "bar2"}
+    util.write_file(config_instance.args["base_config"][1], util.safe_dump(contents))
+    result = config_instance._get_config()
+
+    assert result["foo"] == "bar"
+    assert result["foo2"] == "bar2"
+
+
 def test_reget_config(config_instance):
     assert isinstance(config_instance._reget_config(), dict)
 
@@ -348,3 +360,22 @@ def test_write_config(config_instance):
     config_instance.write()
 
     assert os.path.isfile(config_instance.config_file)
+
+
+@pytest.mark.parametrize(
+    "input,output",
+    [
+        ("ansible 2.9.18", "2.9.18"),  # ansible < 2.10 and ansible-base
+        ("ansible [core 2.11.0b1.post0]", "2.11.0b1.post0"),  # ansible-core
+    ],
+)
+def test_ansible_version_parsing(mocker, input, output):
+    run_command = mocker.patch.object(config, "run_command")
+    run_command.return_value.returncode = 0
+    run_command.return_value.stdout = input + "\nother stuff\n  here\n"
+
+    # Results from ansible_version are cached, so we need to kill the cache before each
+    # test so that we can actually test parsing of different strings.
+    config.ansible_version.cache_clear()
+
+    assert output == str(config.ansible_version())
