@@ -21,15 +21,16 @@
 from __future__ import print_function
 
 import contextlib
+import copy
 import fnmatch
+import logging
 import os
 import re
 import sys
-from collections.abc import Mapping
 from dataclasses import dataclass
 from functools import lru_cache  # noqa
-from subprocess import CompletedProcess
-from typing import Any, Dict, List, NoReturn, Optional, Union
+from subprocess import CalledProcessError, CompletedProcess
+from typing import Any, Dict, List, MutableMapping, NoReturn, Optional, Union
 
 import jinja2
 import yaml
@@ -38,9 +39,8 @@ from subprocess_tee import run
 
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
-from molecule.logger import get_logger
 
-LOG = get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class SafeDumper(yaml.SafeDumper):
@@ -81,19 +81,22 @@ def print_environment_vars(env: Optional[Dict[str, str]]) -> None:
         print()
 
 
+def do_report() -> None:
+    """Dump html report atexit."""
+    report_file = os.environ["MOLECULE_REPORT"]
+    LOG.info("Writing %s report.", report_file)
+    with open(report_file, "w") as f:
+        f.write(console.export_html())
+        f.close()
+
+
 def sysexit(code: int = 1) -> NoReturn:
     """Perform a system exit with given code, default 1."""
-    if "MOLECULE_REPORT" in os.environ:
-        report_file = os.environ["MOLECULE_REPORT"]
-        LOG.info("Writing %s report.", report_file)
-        with open(report_file, "w") as f:
-            f.write(console.export_html())
-
     sys.exit(code)
 
 
 def sysexit_with_message(
-    msg: str, code: int = 1, detail: Optional[Dict] = None
+    msg: str, code: int = 1, detail: Optional[MutableMapping] = None
 ) -> None:
     """Exit with an error message."""
     # detail is usually a multi-line string which is not suitable for normal
@@ -109,7 +112,7 @@ def sysexit_with_message(
 
 
 def run_command(
-    cmd, env=None, debug=False, echo=False, quiet=False
+    cmd, env=None, debug=False, echo=False, quiet=False, check=False, cwd=None
 ) -> CompletedProcess:
     """
     Execute the given command and returns None.
@@ -118,7 +121,6 @@ def run_command(
         - a string or list of strings (similar to subprocess.run)
         - a BakedCommand object (
     :param debug: An optional bool to toggle debug output.
-    :return: ``sh`` object
     """
     args = []
     stdout = None
@@ -139,14 +141,28 @@ def run_command(
     if debug:
         print_environment_vars(env)
 
-    return run(
-        args, env=env, stdout=stdout, stderr=stderr, echo=echo or debug, quiet=quiet
+    result = run(
+        args,
+        env=env,
+        stdout=stdout,
+        stderr=stderr,
+        echo=echo or debug,
+        quiet=quiet,
+        cwd=cwd,
     )
+    if result.returncode != 0 and check:
+        raise CalledProcessError(
+            returncode=result.returncode,
+            cmd=result.args,
+            output=result.stdout,
+            stderr=result.stderr,
+        )
+    return result
 
 
-def os_walk(directory, pattern, excludes=[]):
+def os_walk(directory, pattern, excludes=[], followlinks=False):
     """Navigate recursively and retried files based on pattern."""
-    for root, dirs, files in os.walk(directory, topdown=True):
+    for root, dirs, files in os.walk(directory, topdown=True, followlinks=followlinks):
         dirs[:] = [d for d in dirs if d not in excludes]
         for basename in files:
             if fnmatch.fnmatch(basename, pattern):
@@ -163,7 +179,7 @@ def render_template(template, **kwargs):
     return t.render(kwargs)
 
 
-def write_file(filename, content):
+def write_file(filename: str, content: str):
     """
     Write a file with the given filename and content and returns None.
 
@@ -177,12 +193,12 @@ def write_file(filename, content):
     file_prepender(filename)
 
 
-def molecule_prepender(content):
+def molecule_prepender(content: str):
     """Return molecule identification header."""
     return MOLECULE_HEADER + "\n\n" + content
 
 
-def file_prepender(filename):
+def file_prepender(filename: str):
     """
     Prepend an informational header on files managed by Molecule and returns \
     None.
@@ -222,7 +238,7 @@ def safe_load(string) -> Dict:
     return {}
 
 
-def safe_load_file(filename):
+def safe_load_file(filename: str):
     """
     Parse the provided YAML file and returns a dict.
 
@@ -278,7 +294,7 @@ def abs_path(path):
         return os.path.abspath(path)
 
 
-def merge_dicts(a, b):
+def merge_dicts(a: MutableMapping, b: MutableMapping) -> MutableMapping:
     """
     Merge the values of b into a and returns a new dict.
 
@@ -288,10 +304,10 @@ def merge_dicts(a, b):
     :param b: the dictionary to import
     :return: dict
     """
-    result = a.copy()
+    result = copy.deepcopy(a)
 
     for k, v in b.items():
-        if k in a and isinstance(a[k], Mapping) and isinstance(v, Mapping):
+        if k in a and isinstance(a[k], dict) and isinstance(v, dict):
             result[k] = merge_dicts(a[k], v)
         else:
             result[k] = v
@@ -314,24 +330,27 @@ def _parallelize_platforms(config, run_uuid):
     return [parallelize(platform) for platform in config["platforms"]]
 
 
-def find_vcs_root(test, dirs=(".git", ".hg", ".svn"), default=None) -> str:
+@lru_cache()
+def find_vcs_root(location="", dirs=(".git", ".hg", ".svn"), default=None) -> str:
     """Return current repository root directory."""
-    prev, test = None, os.path.abspath(test)
-    while prev != test:
-        if any(os.path.isdir(os.path.join(test, d)) for d in dirs):
-            return test
-        prev, test = test, os.path.abspath(os.path.join(test, os.pardir))
+    if not location:
+        location = os.getcwd()
+    prev, location = None, os.path.abspath(location)
+    while prev != location:
+        if any(os.path.isdir(os.path.join(location, d)) for d in dirs):
+            return location
+        prev, location = location, os.path.abspath(os.path.join(location, os.pardir))
     return default
 
 
-def lookup_config_file(filename: str) -> str:
+def lookup_config_file(filename: str) -> Optional[str]:
     """Return config file PATH."""
-    for path in [find_vcs_root(os.getcwd(), default="~"), "~"]:
+    for path in [find_vcs_root(default="~"), "~"]:
         f = os.path.expanduser("%s/%s" % (path, filename))
         if os.path.isfile(f):
             LOG.info("Found config file %s", f)
             return f
-    return f
+    return None
 
 
 def boolean(value: Any, strict=True) -> bool:
